import { csvParse, select } from 'd3';
import topojson from 'topojson-client';
import { map } from './map';
import './styles.css';

const worldAtlasURL =
  'https://unpkg.com/visionscarto-world-atlas@0.1.0/world/110m.json';

const citiesURL =
  'https://gist.githubusercontent.com/curran/a59ef43debb9fcfd38858d0be4f3b087/raw/a56bdbdb758eebf6a387d47e4d428258e5cb2abd/worldcitiesReduced.csv';

export const main = (container, { state, setState }) => {
  const width = window.innerWidth;
  const height = window.innerHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  // state.data could be:
  // * undefined
  // * 'LOADING'
  // * An array of objects
  const { countries, cities } = state;

  if (
    countries &&
    countries !== 'LOADING' &&
    cities &&
    cities !== 'LOADING'
  ) {
    svg.call(map, {
      countries,
      cities,
    });
  }

  if (countries === undefined) {
    setState((state) => ({
      ...state,
      countries: 'LOADING',
    }));
    fetch(worldAtlasURL)
      .then((response) => response.json())
      .then((topoJSONData) => {
        const countries = topojson.feature(
          topoJSONData,
          'countries',
        );
        setState((state) => ({
          ...state,
          countries,
        }));
      });
    return;
  }

  if (cities === undefined) {
    setState((state) => ({
      ...state,
      cities: 'LOADING',
    }));
    fetch(citiesURL)
      .then((response) => response.text())
      .then((csvString) => {
        const cities = csvParse(csvString, (d) => {
          d.lat = +d.lat;
          d.lng = +d.lng;
          d.population = +d.population;
          return d;
        });

        setState((state) => ({
          ...state,
          cities,
        }));
      });
    return;
  }
};
