import {
  geoNaturalEarth1,
  geoPath,
  geoGraticule,
} from 'd3';

const projection = geoNaturalEarth1();
const path = geoPath(projection);
const graticule = geoGraticule();

export const map = (
  selection,
  { countries, cities }
) => {
  selection
    .selectAll('path.graticule')
    .data([null])
    .join('path')
    .attr('class', 'graticule')
    .attr('d', path(graticule()))
    .attr('fill', 'none')
    .attr('stroke', '#BBB')
    .attr('stroke-width', 0.2);

  selection
    .selectAll('path.country')
    .data(countries.features)
    .join('path')
    .attr('d', path)
    .attr('class', 'country');

  for (const d of cities) {
    const [x, y] = projection([d.lng, d.lat]);
    d.x = x;
    d.y = y;
  }

  selection
    .selectAll('circle')
    .data(cities)
    .join('circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y)
    .attr('r', 0.2);
  
  
  selection
    .selectAll('path.outline')
    .data([null])
    .join('path')
    .attr('class', 'outline')
    .attr('d', path(graticule.outline()))
    .attr('fill', 'none')
    .attr('stroke', 'black')
    .attr('stroke-width', 1);
};
